Class: Aws::IoTManagedIntegrations::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IoTManagedIntegrations::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/client.rb
Overview
An API client for IoTManagedIntegrations. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IoTManagedIntegrations::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_account_association(params = {}) ⇒ Types::CreateAccountAssociationResponse
Creates a new account association via the destination id.
-
#create_cloud_connector(params = {}) ⇒ Types::CreateCloudConnectorResponse
Creates a C2C (cloud-to-cloud) connector.
-
#create_connector_destination(params = {}) ⇒ Types::CreateConnectorDestinationResponse
Create a connector destination for connecting a cloud-to-cloud (C2C) connector to the customer’s Amazon Web Services account.
-
#create_credential_locker(params = {}) ⇒ Types::CreateCredentialLockerResponse
Create a credential locker.
-
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Create a notification destination such as Kinesis Data Streams that receive events and notifications from Managed integrations.
-
#create_event_log_configuration(params = {}) ⇒ Types::CreateEventLogConfigurationResponse
Set the event log configuration for the account, resource type, or specific resource.
-
#create_managed_thing(params = {}) ⇒ Types::CreateManagedThingResponse
Creates a managed thing.
-
#create_notification_configuration(params = {}) ⇒ Types::CreateNotificationConfigurationResponse
Creates a notification configuration.
-
#create_ota_task(params = {}) ⇒ Types::CreateOtaTaskResponse
Create an over-the-air (OTA) task to target a device.
-
#create_ota_task_configuration(params = {}) ⇒ Types::CreateOtaTaskConfigurationResponse
Create a configuraiton for the over-the-air (OTA) task.
-
#create_provisioning_profile(params = {}) ⇒ Types::CreateProvisioningProfileResponse
Create a provisioning profile for executing device provisioning flows.
-
#delete_account_association(params = {}) ⇒ Struct
Remove a third-party account association for an end user.
-
#delete_cloud_connector(params = {}) ⇒ Struct
Delete a cloud connector.
-
#delete_connector_destination(params = {}) ⇒ Struct
Delete a connector destination linked to a cloud-to-cloud (C2C) connector.
-
#delete_credential_locker(params = {}) ⇒ Struct
Delete a credential locker.
-
#delete_destination(params = {}) ⇒ Struct
Deletes a notification destination specified by name.
-
#delete_event_log_configuration(params = {}) ⇒ Struct
Delete an event log configuration.
-
#delete_managed_thing(params = {}) ⇒ Struct
Delete a managed thing.
-
#delete_notification_configuration(params = {}) ⇒ Struct
Deletes a notification configuration.
-
#delete_ota_task(params = {}) ⇒ Struct
Delete the over-the-air (OTA) task.
-
#delete_ota_task_configuration(params = {}) ⇒ Struct
Delete the over-the-air (OTA) task configuration.
-
#delete_provisioning_profile(params = {}) ⇒ Struct
Delete a provisioning profile.
-
#deregister_account_association(params = {}) ⇒ Struct
Deregister an account association from a managed thing.
-
#get_account_association(params = {}) ⇒ Types::GetAccountAssociationResponse
Get an account association for an Amazon Web Services account linked to a customer-managed destination.
-
#get_cloud_connector(params = {}) ⇒ Types::GetCloudConnectorResponse
Get configuration details for a cloud connector.
-
#get_connector_destination(params = {}) ⇒ Types::GetConnectorDestinationResponse
Get connector destination details linked to a cloud-to-cloud (C2C) connector.
-
#get_credential_locker(params = {}) ⇒ Types::GetCredentialLockerResponse
Get information on an existing credential locker.
-
#get_custom_endpoint(params = {}) ⇒ Types::GetCustomEndpointResponse
Returns the IoT managed integrations custom endpoint.
-
#get_default_encryption_configuration(params = {}) ⇒ Types::GetDefaultEncryptionConfigurationResponse
Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified region.
-
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Gets a destination by name.
-
#get_device_discovery(params = {}) ⇒ Types::GetDeviceDiscoveryResponse
Get the current state of a device discovery.
-
#get_event_log_configuration(params = {}) ⇒ Types::GetEventLogConfigurationResponse
Get an event log configuration.
-
#get_hub_configuration(params = {}) ⇒ Types::GetHubConfigurationResponse
Get a hub configuration.
-
#get_managed_thing(params = {}) ⇒ Types::GetManagedThingResponse
Get details of a managed thing including its attributes and capabilities.
-
#get_managed_thing_capabilities(params = {}) ⇒ Types::GetManagedThingCapabilitiesResponse
Get the capabilities for a managed thing using the device ID.
-
#get_managed_thing_certificate(params = {}) ⇒ Types::GetManagedThingCertificateResponse
Retrieves the certificate PEM for a managed IoT thing.
-
#get_managed_thing_connectivity_data(params = {}) ⇒ Types::GetManagedThingConnectivityDataResponse
Get the connectivity status of a managed thing.
-
#get_managed_thing_meta_data(params = {}) ⇒ Types::GetManagedThingMetaDataResponse
Get the metadata information for a managed thing.
-
#get_managed_thing_state(params = {}) ⇒ Types::GetManagedThingStateResponse
Returns the managed thing state for the given device Id.
-
#get_notification_configuration(params = {}) ⇒ Types::GetNotificationConfigurationResponse
Get a notification configuration for a specified event type.
-
#get_ota_task(params = {}) ⇒ Types::GetOtaTaskResponse
Get details of the over-the-air (OTA) task by its task id.
-
#get_ota_task_configuration(params = {}) ⇒ Types::GetOtaTaskConfigurationResponse
Get a configuraiton for the over-the-air (OTA) task.
-
#get_provisioning_profile(params = {}) ⇒ Types::GetProvisioningProfileResponse
Get details of a provisioning profile.
-
#get_runtime_log_configuration(params = {}) ⇒ Types::GetRuntimeLogConfigurationResponse
Get the runtime log configuration for a specific managed thing.
-
#get_schema_version(params = {}) ⇒ Types::GetSchemaVersionResponse
Gets a schema version with the provided information.
-
#list_account_associations(params = {}) ⇒ Types::ListAccountAssociationsResponse
Lists all account associations, with optional filtering by connector destination ID.
-
#list_cloud_connectors(params = {}) ⇒ Types::ListCloudConnectorsResponse
Returns a list of connectors filtered by its Lambda Amazon Resource Name (ARN) and ‘type`.
-
#list_connector_destinations(params = {}) ⇒ Types::ListConnectorDestinationsResponse
Lists all connector destinations, with optional filtering by cloud connector ID.
-
#list_credential_lockers(params = {}) ⇒ Types::ListCredentialLockersResponse
List information on an existing credential locker.
-
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
List all notification destinations.
-
#list_device_discoveries(params = {}) ⇒ Types::ListDeviceDiscoveriesResponse
Lists all device discovery tasks, with optional filtering by type and status.
-
#list_discovered_devices(params = {}) ⇒ Types::ListDiscoveredDevicesResponse
Lists all devices discovered during a specific device discovery task.
-
#list_event_log_configurations(params = {}) ⇒ Types::ListEventLogConfigurationsResponse
List all event log configurations for an account.
-
#list_managed_thing_account_associations(params = {}) ⇒ Types::ListManagedThingAccountAssociationsResponse
Lists all account associations for a specific managed thing.
-
#list_managed_thing_schemas(params = {}) ⇒ Types::ListManagedThingSchemasResponse
List schemas associated with a managed thing.
-
#list_managed_things(params = {}) ⇒ Types::ListManagedThingsResponse
Listing all managed things with provision for filters.
-
#list_notification_configurations(params = {}) ⇒ Types::ListNotificationConfigurationsResponse
List all notification configurations.
-
#list_ota_task_configurations(params = {}) ⇒ Types::ListOtaTaskConfigurationsResponse
List all of the over-the-air (OTA) task configurations.
-
#list_ota_task_executions(params = {}) ⇒ Types::ListOtaTaskExecutionsResponse
List all of the over-the-air (OTA) task executions.
-
#list_ota_tasks(params = {}) ⇒ Types::ListOtaTasksResponse
List all of the over-the-air (OTA) tasks.
-
#list_provisioning_profiles(params = {}) ⇒ Types::ListProvisioningProfilesResponse
List the provisioning profiles within the Amazon Web Services account.
-
#list_schema_versions(params = {}) ⇒ Types::ListSchemaVersionsResponse
Lists schema versions with the provided information.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a specified resource.
-
#put_default_encryption_configuration(params = {}) ⇒ Types::PutDefaultEncryptionConfigurationResponse
Sets the default encryption configuration for the Amazon Web Services account.
-
#put_hub_configuration(params = {}) ⇒ Types::PutHubConfigurationResponse
Update a hub configuration.
-
#put_runtime_log_configuration(params = {}) ⇒ Struct
Set the runtime log configuration for a specific managed thing.
-
#register_account_association(params = {}) ⇒ Types::RegisterAccountAssociationResponse
Registers an account association with a managed thing, establishing a connection between a device and a third-party account.
-
#register_custom_endpoint(params = {}) ⇒ Types::RegisterCustomEndpointResponse
Customers can request IoT managed integrations to manage the server trust for them or bring their own external server trusts for the custom domain.
-
#reset_runtime_log_configuration(params = {}) ⇒ Struct
Reset a runtime log configuration for a specific managed thing.
-
#send_connector_event(params = {}) ⇒ Types::SendConnectorEventResponse
Relays third-party device events for a connector such as a new device or a device state change event.
-
#send_managed_thing_command(params = {}) ⇒ Types::SendManagedThingCommandResponse
Send the command to the device represented by the managed thing.
-
#start_account_association_refresh(params = {}) ⇒ Types::StartAccountAssociationRefreshResponse
Initiates a refresh of an existing account association to update its authorization and connection status.
-
#start_device_discovery(params = {}) ⇒ Types::StartDeviceDiscoveryResponse
This API is used to start device discovery for hub-connected and third-party-connected devices.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a specified resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
-
#update_account_association(params = {}) ⇒ Struct
Updates the properties of an existing account association.
-
#update_cloud_connector(params = {}) ⇒ Struct
Update an existing cloud connector.
-
#update_connector_destination(params = {}) ⇒ Struct
Updates the properties of an existing connector destination.
-
#update_destination(params = {}) ⇒ Struct
Update a destination specified by name.
-
#update_event_log_configuration(params = {}) ⇒ Struct
Update an event log configuration by log configuration ID.
-
#update_managed_thing(params = {}) ⇒ Struct
Update the attributes and capabilities associated with a managed thing.
-
#update_notification_configuration(params = {}) ⇒ Struct
Update a notification configuration.
-
#update_ota_task(params = {}) ⇒ Struct
Update an over-the-air (OTA) task.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4460 4461 4462 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4460 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4463 4464 4465 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4463 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4433 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IoTManagedIntegrations') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-iotmanagedintegrations' context[:gem_version] = '1.23.0' Seahorse::Client::Request.new(handlers, context) end |
#create_account_association(params = {}) ⇒ Types::CreateAccountAssociationResponse
Creates a new account association via the destination id.
535 536 537 538 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 535 def create_account_association(params = {}, = {}) req = build_request(:create_account_association, params) req.send_request() end |
#create_cloud_connector(params = {}) ⇒ Types::CreateCloudConnectorResponse
Creates a C2C (cloud-to-cloud) connector.
639 640 641 642 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 639 def create_cloud_connector(params = {}, = {}) req = build_request(:create_cloud_connector, params) req.send_request() end |
#create_connector_destination(params = {}) ⇒ Types::CreateConnectorDestinationResponse
Create a connector destination for connecting a cloud-to-cloud (C2C) connector to the customer’s Amazon Web Services account.
724 725 726 727 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 724 def create_connector_destination(params = {}, = {}) req = build_request(:create_connector_destination, params) req.send_request() end |
#create_credential_locker(params = {}) ⇒ Types::CreateCredentialLockerResponse
Create a credential locker.
<note markdown=“1”> This operation will not trigger the creation of all the manufacturing resources.
</note>
776 777 778 779 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 776 def create_credential_locker(params = {}, = {}) req = build_request(:create_credential_locker, params) req.send_request() end |
#create_destination(params = {}) ⇒ Types::CreateDestinationResponse
Create a notification destination such as Kinesis Data Streams that receive events and notifications from Managed integrations. Managed integrations uses the destination to determine where to deliver notifications.
837 838 839 840 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 837 def create_destination(params = {}, = {}) req = build_request(:create_destination, params) req.send_request() end |
#create_event_log_configuration(params = {}) ⇒ Types::CreateEventLogConfigurationResponse
Set the event log configuration for the account, resource type, or specific resource.
882 883 884 885 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 882 def create_event_log_configuration(params = {}, = {}) req = build_request(:create_event_log_configuration, params) req.send_request() end |
#create_managed_thing(params = {}) ⇒ Types::CreateManagedThingResponse
Creates a managed thing. A managed thing contains the device identifier, protocol supported, and capabilities of the device in a data model format defined by Managed integrations.
1036 1037 1038 1039 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1036 def create_managed_thing(params = {}, = {}) req = build_request(:create_managed_thing, params) req.send_request() end |
#create_notification_configuration(params = {}) ⇒ Types::CreateNotificationConfigurationResponse
Creates a notification configuration. A configuration is a connection between an event type and a destination that you have already created.
1085 1086 1087 1088 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1085 def create_notification_configuration(params = {}, = {}) req = build_request(:create_notification_configuration, params) req.send_request() end |
#create_ota_task(params = {}) ⇒ Types::CreateOtaTaskResponse
Create an over-the-air (OTA) task to target a device.
1187 1188 1189 1190 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1187 def create_ota_task(params = {}, = {}) req = build_request(:create_ota_task, params) req.send_request() end |
#create_ota_task_configuration(params = {}) ⇒ Types::CreateOtaTaskConfigurationResponse
Create a configuraiton for the over-the-air (OTA) task.
1257 1258 1259 1260 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1257 def create_ota_task_configuration(params = {}, = {}) req = build_request(:create_ota_task_configuration, params) req.send_request() end |
#create_provisioning_profile(params = {}) ⇒ Types::CreateProvisioningProfileResponse
Create a provisioning profile for executing device provisioning flows. The provisioning profile is a document that defines the set of resources and policies applied to a device during the provisioning process.
1330 1331 1332 1333 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1330 def create_provisioning_profile(params = {}, = {}) req = build_request(:create_provisioning_profile, params) req.send_request() end |
#delete_account_association(params = {}) ⇒ Struct
Remove a third-party account association for an end user.
<note markdown=“1”> You must first call the ‘DeregisterAccountAssociation` to remove the connection between the managed thing and the third-party account before calling the `DeleteAccountAssociation` API.
</note>
1356 1357 1358 1359 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1356 def delete_account_association(params = {}, = {}) req = build_request(:delete_account_association, params) req.send_request() end |
#delete_cloud_connector(params = {}) ⇒ Struct
Delete a cloud connector.
1376 1377 1378 1379 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1376 def delete_cloud_connector(params = {}, = {}) req = build_request(:delete_cloud_connector, params) req.send_request() end |
#delete_connector_destination(params = {}) ⇒ Struct
Delete a connector destination linked to a cloud-to-cloud (C2C) connector.
<note markdown=“1”> Deletion can’t be done if the account association has used this connector destination.
</note>
1402 1403 1404 1405 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1402 def delete_connector_destination(params = {}, = {}) req = build_request(:delete_connector_destination, params) req.send_request() end |
#delete_credential_locker(params = {}) ⇒ Struct
Delete a credential locker.
<note markdown=“1”> This operation can’t be undone and any existing device won’t be able to use IoT managed integrations.
</note>
1427 1428 1429 1430 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1427 def delete_credential_locker(params = {}, = {}) req = build_request(:delete_credential_locker, params) req.send_request() end |
#delete_destination(params = {}) ⇒ Struct
Deletes a notification destination specified by name.
1447 1448 1449 1450 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1447 def delete_destination(params = {}, = {}) req = build_request(:delete_destination, params) req.send_request() end |
#delete_event_log_configuration(params = {}) ⇒ Struct
Delete an event log configuration.
1467 1468 1469 1470 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1467 def delete_event_log_configuration(params = {}, = {}) req = build_request(:delete_event_log_configuration, params) req.send_request() end |
#delete_managed_thing(params = {}) ⇒ Struct
Delete a managed thing. For direct-connected and hub-connected devices connecting with Managed integrations via a controller, all of the devices connected to it will have their status changed to ‘PENDING`. It is not possible to remove a cloud-to-cloud device.
1496 1497 1498 1499 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1496 def delete_managed_thing(params = {}, = {}) req = build_request(:delete_managed_thing, params) req.send_request() end |
#delete_notification_configuration(params = {}) ⇒ Struct
Deletes a notification configuration.
1517 1518 1519 1520 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1517 def delete_notification_configuration(params = {}, = {}) req = build_request(:delete_notification_configuration, params) req.send_request() end |
#delete_ota_task(params = {}) ⇒ Struct
Delete the over-the-air (OTA) task.
1537 1538 1539 1540 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1537 def delete_ota_task(params = {}, = {}) req = build_request(:delete_ota_task, params) req.send_request() end |
#delete_ota_task_configuration(params = {}) ⇒ Struct
Delete the over-the-air (OTA) task configuration.
1557 1558 1559 1560 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1557 def delete_ota_task_configuration(params = {}, = {}) req = build_request(:delete_ota_task_configuration, params) req.send_request() end |
#delete_provisioning_profile(params = {}) ⇒ Struct
Delete a provisioning profile.
1577 1578 1579 1580 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1577 def delete_provisioning_profile(params = {}, = {}) req = build_request(:delete_provisioning_profile, params) req.send_request() end |
#deregister_account_association(params = {}) ⇒ Struct
Deregister an account association from a managed thing.
1602 1603 1604 1605 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1602 def deregister_account_association(params = {}, = {}) req = build_request(:deregister_account_association, params) req.send_request() end |
#get_account_association(params = {}) ⇒ Types::GetAccountAssociationResponse
Get an account association for an Amazon Web Services account linked to a customer-managed destination.
1648 1649 1650 1651 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1648 def get_account_association(params = {}, = {}) req = build_request(:get_account_association, params) req.send_request() end |
#get_cloud_connector(params = {}) ⇒ Types::GetCloudConnectorResponse
Get configuration details for a cloud connector.
1725 1726 1727 1728 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1725 def get_cloud_connector(params = {}, = {}) req = build_request(:get_cloud_connector, params) req.send_request() end |
#get_connector_destination(params = {}) ⇒ Types::GetConnectorDestinationResponse
Get connector destination details linked to a cloud-to-cloud (C2C) connector.
1777 1778 1779 1780 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1777 def get_connector_destination(params = {}, = {}) req = build_request(:get_connector_destination, params) req.send_request() end |
#get_credential_locker(params = {}) ⇒ Types::GetCredentialLockerResponse
Get information on an existing credential locker
1812 1813 1814 1815 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1812 def get_credential_locker(params = {}, = {}) req = build_request(:get_credential_locker, params) req.send_request() end |
#get_custom_endpoint(params = {}) ⇒ Types::GetCustomEndpointResponse
Returns the IoT managed integrations custom endpoint.
1829 1830 1831 1832 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1829 def get_custom_endpoint(params = {}, = {}) req = build_request(:get_custom_endpoint, params) req.send_request() end |
#get_default_encryption_configuration(params = {}) ⇒ Types::GetDefaultEncryptionConfigurationResponse
Retrieves information about the default encryption configuration for the Amazon Web Services account in the default or specified region. For more information, see [Key management] in the *AWS IoT SiteWise User Guide*.
[1]: docs.aws.amazon.com/iot-sitewise/latest/userguide/key-management.html
1859 1860 1861 1862 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1859 def get_default_encryption_configuration(params = {}, = {}) req = build_request(:get_default_encryption_configuration, params) req.send_request() end |
#get_destination(params = {}) ⇒ Types::GetDestinationResponse
Gets a destination by name.
1900 1901 1902 1903 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1900 def get_destination(params = {}, = {}) req = build_request(:get_destination, params) req.send_request() end |
#get_device_discovery(params = {}) ⇒ Types::GetDeviceDiscoveryResponse
Get the current state of a device discovery.
1945 1946 1947 1948 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1945 def get_device_discovery(params = {}, = {}) req = build_request(:get_device_discovery, params) req.send_request() end |
#get_event_log_configuration(params = {}) ⇒ Types::GetEventLogConfigurationResponse
Get an event log configuration.
1977 1978 1979 1980 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1977 def get_event_log_configuration(params = {}, = {}) req = build_request(:get_event_log_configuration, params) req.send_request() end |
#get_hub_configuration(params = {}) ⇒ Types::GetHubConfigurationResponse
Get a hub configuration.
1996 1997 1998 1999 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 1996 def get_hub_configuration(params = {}, = {}) req = build_request(:get_hub_configuration, params) req.send_request() end |
#get_managed_thing(params = {}) ⇒ Types::GetManagedThingResponse
Get details of a managed thing including its attributes and capabilities.
2079 2080 2081 2082 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2079 def get_managed_thing(params = {}, = {}) req = build_request(:get_managed_thing, params) req.send_request() end |
#get_managed_thing_capabilities(params = {}) ⇒ Types::GetManagedThingCapabilitiesResponse
Get the capabilities for a managed thing using the device ID.
2124 2125 2126 2127 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2124 def get_managed_thing_capabilities(params = {}, = {}) req = build_request(:get_managed_thing_capabilities, params) req.send_request() end |
#get_managed_thing_certificate(params = {}) ⇒ Types::GetManagedThingCertificateResponse
Retrieves the certificate PEM for a managed IoT thing.
2165 2166 2167 2168 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2165 def get_managed_thing_certificate(params = {}, = {}) req = build_request(:get_managed_thing_certificate, params) req.send_request() end |
#get_managed_thing_connectivity_data(params = {}) ⇒ Types::GetManagedThingConnectivityDataResponse
Get the connectivity status of a managed thing.
2197 2198 2199 2200 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2197 def get_managed_thing_connectivity_data(params = {}, = {}) req = build_request(:get_managed_thing_connectivity_data, params) req.send_request() end |
#get_managed_thing_meta_data(params = {}) ⇒ Types::GetManagedThingMetaDataResponse
Get the metadata information for a managed thing.
<note markdown=“1”> The ‘managedThing` `metadata` parameter is used for associating attributes with a `managedThing` that can be used for grouping over-the-air (OTA) tasks. Name value pairs in `metadata` can be used in the `OtaTargetQueryString` parameter for the `CreateOtaTask` API operation.
</note>
2234 2235 2236 2237 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2234 def (params = {}, = {}) req = build_request(:get_managed_thing_meta_data, params) req.send_request() end |
#get_managed_thing_state(params = {}) ⇒ Types::GetManagedThingStateResponse
Returns the managed thing state for the given device Id.
2265 2266 2267 2268 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2265 def get_managed_thing_state(params = {}, = {}) req = build_request(:get_managed_thing_state, params) req.send_request() end |
#get_notification_configuration(params = {}) ⇒ Types::GetNotificationConfigurationResponse
Get a notification configuration for a specified event type.
2301 2302 2303 2304 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2301 def get_notification_configuration(params = {}, = {}) req = build_request(:get_notification_configuration, params) req.send_request() end |
#get_ota_task(params = {}) ⇒ Types::GetOtaTaskResponse
Get details of the over-the-air (OTA) task by its task id.
2377 2378 2379 2380 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2377 def get_ota_task(params = {}, = {}) req = build_request(:get_ota_task, params) req.send_request() end |
#get_ota_task_configuration(params = {}) ⇒ Types::GetOtaTaskConfigurationResponse
Get a configuraiton for the over-the-air (OTA) task.
2421 2422 2423 2424 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2421 def get_ota_task_configuration(params = {}, = {}) req = build_request(:get_ota_task_configuration, params) req.send_request() end |
#get_provisioning_profile(params = {}) ⇒ Types::GetProvisioningProfileResponse
Get details of a provisioning profile.
2460 2461 2462 2463 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2460 def get_provisioning_profile(params = {}, = {}) req = build_request(:get_provisioning_profile, params) req.send_request() end |
#get_runtime_log_configuration(params = {}) ⇒ Types::GetRuntimeLogConfigurationResponse
Get the runtime log configuration for a specific managed thing.
2495 2496 2497 2498 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2495 def get_runtime_log_configuration(params = {}, = {}) req = build_request(:get_runtime_log_configuration, params) req.send_request() end |
#get_schema_version(params = {}) ⇒ Types::GetSchemaVersionResponse
Gets a schema version with the provided information.
2541 2542 2543 2544 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2541 def get_schema_version(params = {}, = {}) req = build_request(:get_schema_version, params) req.send_request() end |
#list_account_associations(params = {}) ⇒ Types::ListAccountAssociationsResponse
Lists all account associations, with optional filtering by connector destination ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2589 2590 2591 2592 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2589 def list_account_associations(params = {}, = {}) req = build_request(:list_account_associations, params) req.send_request() end |
#list_cloud_connectors(params = {}) ⇒ Types::ListCloudConnectorsResponse
Returns a list of connectors filtered by its Lambda Amazon Resource Name (ARN) and ‘type`.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2679 2680 2681 2682 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2679 def list_cloud_connectors(params = {}, = {}) req = build_request(:list_cloud_connectors, params) req.send_request() end |
#list_connector_destinations(params = {}) ⇒ Types::ListConnectorDestinationsResponse
Lists all connector destinations, with optional filtering by cloud connector ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2724 2725 2726 2727 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2724 def list_connector_destinations(params = {}, = {}) req = build_request(:list_connector_destinations, params) req.send_request() end |
#list_credential_lockers(params = {}) ⇒ Types::ListCredentialLockersResponse
List information on an existing credential locker.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2762 2763 2764 2765 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2762 def list_credential_lockers(params = {}, = {}) req = build_request(:list_credential_lockers, params) req.send_request() end |
#list_destinations(params = {}) ⇒ Types::ListDestinationsResponse
List all notification destinations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2801 2802 2803 2804 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2801 def list_destinations(params = {}, = {}) req = build_request(:list_destinations, params) req.send_request() end |
#list_device_discoveries(params = {}) ⇒ Types::ListDeviceDiscoveriesResponse
Lists all device discovery tasks, with optional filtering by type and status.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2848 2849 2850 2851 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2848 def list_device_discoveries(params = {}, = {}) req = build_request(:list_device_discoveries, params) req.send_request() end |
#list_discovered_devices(params = {}) ⇒ Types::ListDiscoveredDevicesResponse
Lists all devices discovered during a specific device discovery task.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2898 2899 2900 2901 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2898 def list_discovered_devices(params = {}, = {}) req = build_request(:list_discovered_devices, params) req.send_request() end |
#list_event_log_configurations(params = {}) ⇒ Types::ListEventLogConfigurationsResponse
List all event log configurations for an account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2936 2937 2938 2939 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2936 def list_event_log_configurations(params = {}, = {}) req = build_request(:list_event_log_configurations, params) req.send_request() end |
#list_managed_thing_account_associations(params = {}) ⇒ Types::ListManagedThingAccountAssociationsResponse
Lists all account associations for a specific managed thing.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2984 2985 2986 2987 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 2984 def list_managed_thing_account_associations(params = {}, = {}) req = build_request(:list_managed_thing_account_associations, params) req.send_request() end |
#list_managed_thing_schemas(params = {}) ⇒ Types::ListManagedThingSchemasResponse
List schemas associated with a managed thing.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3032 3033 3034 3035 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3032 def list_managed_thing_schemas(params = {}, = {}) req = build_request(:list_managed_thing_schemas, params) req.send_request() end |
#list_managed_things(params = {}) ⇒ Types::ListManagedThingsResponse
Listing all managed things with provision for filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3130 3131 3132 3133 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3130 def list_managed_things(params = {}, = {}) req = build_request(:list_managed_things, params) req.send_request() end |
#list_notification_configurations(params = {}) ⇒ Types::ListNotificationConfigurationsResponse
List all notification configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3166 3167 3168 3169 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3166 def list_notification_configurations(params = {}, = {}) req = build_request(:list_notification_configurations, params) req.send_request() end |
#list_ota_task_configurations(params = {}) ⇒ Types::ListOtaTaskConfigurationsResponse
List all of the over-the-air (OTA) task configurations.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3203 3204 3205 3206 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3203 def list_ota_task_configurations(params = {}, = {}) req = build_request(:list_ota_task_configurations, params) req.send_request() end |
#list_ota_task_executions(params = {}) ⇒ Types::ListOtaTaskExecutionsResponse
List all of the over-the-air (OTA) task executions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3248 3249 3250 3251 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3248 def list_ota_task_executions(params = {}, = {}) req = build_request(:list_ota_task_executions, params) req.send_request() end |
#list_ota_tasks(params = {}) ⇒ Types::ListOtaTasksResponse
List all of the over-the-air (OTA) tasks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3288 3289 3290 3291 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3288 def list_ota_tasks(params = {}, = {}) req = build_request(:list_ota_tasks, params) req.send_request() end |
#list_provisioning_profiles(params = {}) ⇒ Types::ListProvisioningProfilesResponse
List the provisioning profiles within the Amazon Web Services account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3327 3328 3329 3330 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3327 def list_provisioning_profiles(params = {}, = {}) req = build_request(:list_provisioning_profiles, params) req.send_request() end |
#list_schema_versions(params = {}) ⇒ Types::ListSchemaVersionsResponse
Lists schema versions with the provided information.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
3437 3438 3439 3440 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3437 def list_schema_versions(params = {}, = {}) req = build_request(:list_schema_versions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags for a specified resource.
3464 3465 3466 3467 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3464 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_default_encryption_configuration(params = {}) ⇒ Types::PutDefaultEncryptionConfigurationResponse
Sets the default encryption configuration for the Amazon Web Services account. For more information, see [Key management] in the AWS IoT SiteWise User Guide.
[1]: docs.aws.amazon.com/iot-sitewise/latest/userguide/key-management.html
3507 3508 3509 3510 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3507 def put_default_encryption_configuration(params = {}, = {}) req = build_request(:put_default_encryption_configuration, params) req.send_request() end |
#put_hub_configuration(params = {}) ⇒ Types::PutHubConfigurationResponse
Update a hub configuration.
3534 3535 3536 3537 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3534 def put_hub_configuration(params = {}, = {}) req = build_request(:put_hub_configuration, params) req.send_request() end |
#put_runtime_log_configuration(params = {}) ⇒ Struct
Set the runtime log configuration for a specific managed thing.
3567 3568 3569 3570 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3567 def put_runtime_log_configuration(params = {}, = {}) req = build_request(:put_runtime_log_configuration, params) req.send_request() end |
#register_account_association(params = {}) ⇒ Types::RegisterAccountAssociationResponse
Registers an account association with a managed thing, establishing a connection between a device and a third-party account.
3609 3610 3611 3612 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3609 def register_account_association(params = {}, = {}) req = build_request(:register_account_association, params) req.send_request() end |
#register_custom_endpoint(params = {}) ⇒ Types::RegisterCustomEndpointResponse
Customers can request IoT managed integrations to manage the server trust for them or bring their own external server trusts for the custom domain. Returns an IoT managed integrations endpoint.
3628 3629 3630 3631 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3628 def register_custom_endpoint(params = {}, = {}) req = build_request(:register_custom_endpoint, params) req.send_request() end |
#reset_runtime_log_configuration(params = {}) ⇒ Struct
Reset a runtime log configuration for a specific managed thing.
3648 3649 3650 3651 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3648 def reset_runtime_log_configuration(params = {}, = {}) req = build_request(:reset_runtime_log_configuration, params) req.send_request() end |
#send_connector_event(params = {}) ⇒ Types::SendConnectorEventResponse
Relays third-party device events for a connector such as a new device or a device state change event.
3815 3816 3817 3818 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3815 def send_connector_event(params = {}, = {}) req = build_request(:send_connector_event, params) req.send_request() end |
#send_managed_thing_command(params = {}) ⇒ Types::SendManagedThingCommandResponse
Send the command to the device represented by the managed thing.
3875 3876 3877 3878 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3875 def send_managed_thing_command(params = {}, = {}) req = build_request(:send_managed_thing_command, params) req.send_request() end |
#start_account_association_refresh(params = {}) ⇒ Types::StartAccountAssociationRefreshResponse
Initiates a refresh of an existing account association to update its authorization and connection status.
3902 3903 3904 3905 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 3902 def start_account_association_refresh(params = {}, = {}) req = build_request(:start_account_association_refresh, params) req.send_request() end |
#start_device_discovery(params = {}) ⇒ Types::StartDeviceDiscoveryResponse
This API is used to start device discovery for hub-connected and third-party-connected devices. The authentication material (install code) is delivered as a message to the controller instructing it to start the discovery.
4005 4006 4007 4008 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4005 def start_device_discovery(params = {}, = {}) req = build_request(:start_device_discovery, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a specified resource.
4031 4032 4033 4034 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4031 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a specified resource.
4056 4057 4058 4059 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4056 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_account_association(params = {}) ⇒ Struct
Updates the properties of an existing account association.
4084 4085 4086 4087 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4084 def update_account_association(params = {}, = {}) req = build_request(:update_account_association, params) req.send_request() end |
#update_cloud_connector(params = {}) ⇒ Struct
Update an existing cloud connector.
4127 4128 4129 4130 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4127 def update_cloud_connector(params = {}, = {}) req = build_request(:update_cloud_connector, params) req.send_request() end |
#update_connector_destination(params = {}) ⇒ Struct
Updates the properties of an existing connector destination.
4200 4201 4202 4203 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4200 def update_connector_destination(params = {}, = {}) req = build_request(:update_connector_destination, params) req.send_request() end |
#update_destination(params = {}) ⇒ Struct
Update a destination specified by name.
4236 4237 4238 4239 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4236 def update_destination(params = {}, = {}) req = build_request(:update_destination, params) req.send_request() end |
#update_event_log_configuration(params = {}) ⇒ Struct
Update an event log configuration by log configuration ID.
4260 4261 4262 4263 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4260 def update_event_log_configuration(params = {}, = {}) req = build_request(:update_event_log_configuration, params) req.send_request() end |
#update_managed_thing(params = {}) ⇒ Struct
Update the attributes and capabilities associated with a managed thing.
4371 4372 4373 4374 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4371 def update_managed_thing(params = {}, = {}) req = build_request(:update_managed_thing, params) req.send_request() end |
#update_notification_configuration(params = {}) ⇒ Struct
Update a notification configuration.
4396 4397 4398 4399 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4396 def update_notification_configuration(params = {}, = {}) req = build_request(:update_notification_configuration, params) req.send_request() end |
#update_ota_task(params = {}) ⇒ Struct
Update an over-the-air (OTA) task.
4424 4425 4426 4427 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4424 def update_ota_task(params = {}, = {}) req = build_request(:update_ota_task, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
4453 4454 4455 |
# File 'lib/aws-sdk-iotmanagedintegrations/client.rb', line 4453 def waiter_names [] end |