Class: Aws::IoTManagedIntegrations::Types::CreateCloudConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::CreateCloudConnectorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier assigned to the newly created cloud connector.
Instance Attribute Details
#id ⇒ String
The unique identifier assigned to the newly created cloud connector.
579 580 581 582 583 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 579 class CreateCloudConnectorResponse < Struct.new( :id) SENSITIVE = [] include Aws::Structure end |