Class: Aws::IoTManagedIntegrations::Types::DeleteNotificationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::DeleteNotificationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ String
The type of event triggering a device notification to the customer-managed destination.
Instance Attribute Details
#event_type ⇒ String
The type of event triggering a device notification to the customer-managed destination.
850 851 852 853 854 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 850 class DeleteNotificationConfigurationRequest < Struct.new( :event_type) SENSITIVE = [] include Aws::Structure end |