Class: Aws::IoTManagedIntegrations::Types::EndpointConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotmanagedintegrations/types.rb

Overview

The configuration details for an endpoint, which defines how to connect to and communicate with external services.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambdaTypes::LambdaConfig

The Lambda function configuration for the endpoint, used when the endpoint communicates through an AWS Lambda function.

Returns:



1513
1514
1515
1516
1517
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1513

class EndpointConfig < Struct.new(
  :lambda)
  SENSITIVE = []
  include Aws::Structure
end