Class: Aws::IoTManagedIntegrations::Types::EventLogConfigurationSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotmanagedintegrations/types.rb

Overview

List of event log configurations.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#event_log_levelString

The logging level for the event log configuration.

Returns:

  • (String)


1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1537

class EventLogConfigurationSummary < Struct.new(
  :id,
  :resource_type,
  :resource_id,
  :event_log_level)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The identifier of the event log configuration.

Returns:

  • (String)


1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1537

class EventLogConfigurationSummary < Struct.new(
  :id,
  :resource_type,
  :resource_id,
  :event_log_level)
  SENSITIVE = []
  include Aws::Structure
end

#resource_idString

The identifier of the resource for the event log configuration.

Returns:

  • (String)


1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1537

class EventLogConfigurationSummary < Struct.new(
  :id,
  :resource_type,
  :resource_id,
  :event_log_level)
  SENSITIVE = []
  include Aws::Structure
end

#resource_typeString

The type of resource for the event log configuration.

Returns:

  • (String)


1537
1538
1539
1540
1541
1542
1543
1544
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1537

class EventLogConfigurationSummary < Struct.new(
  :id,
  :resource_type,
  :resource_id,
  :event_log_level)
  SENSITIVE = []
  include Aws::Structure
end