Class: Aws::IoTManagedIntegrations::Types::ExponentialRolloutRate

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotmanagedintegrations/types.rb

Overview

Structure representing exponential rate of rollout for an over-the-air (OTA) task.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#base_rate_per_minuteInteger

The base rate per minute for the rollout of an over-the-air (OTA) task.

Returns:

  • (Integer)


1564
1565
1566
1567
1568
1569
1570
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1564

class ExponentialRolloutRate < Struct.new(
  :base_rate_per_minute,
  :increment_factor,
  :rate_increase_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#increment_factorFloat

The incremental factor for increasing the rollout rate of an over-the-air (OTA) task.

Returns:

  • (Float)


1564
1565
1566
1567
1568
1569
1570
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1564

class ExponentialRolloutRate < Struct.new(
  :base_rate_per_minute,
  :increment_factor,
  :rate_increase_criteria)
  SENSITIVE = []
  include Aws::Structure
end

#rate_increase_criteriaTypes::RolloutRateIncreaseCriteria

The criteria for increasing the rollout rate of an over-the-air (OTA) task.



1564
1565
1566
1567
1568
1569
1570
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1564

class ExponentialRolloutRate < Struct.new(
  :base_rate_per_minute,
  :increment_factor,
  :rate_increase_criteria)
  SENSITIVE = []
  include Aws::Structure
end