Class: Aws::IoTManagedIntegrations::Types::GetAccountAssociationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::GetAccountAssociationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_association_id ⇒ String
The unique identifier of the account association to retrieve.
Instance Attribute Details
#account_association_id ⇒ String
The unique identifier of the account association to retrieve.
1606 1607 1608 1609 1610 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1606 class GetAccountAssociationRequest < Struct.new( :account_association_id) SENSITIVE = [] include Aws::Structure end |