Class: Aws::IoTManagedIntegrations::Types::GetCloudConnectorResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::GetCloudConnectorResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the C2C connector.
-
#endpoint_config ⇒ Types::EndpointConfig
The configuration details for the cloud connector endpoint, including connection parameters and authentication requirements.
-
#endpoint_type ⇒ String
The type of endpoint used for the cloud connector, which defines how the connector communicates with external services.
-
#id ⇒ String
The unique identifier of the cloud connector.
-
#name ⇒ String
The display name of the C2C connector.
-
#type ⇒ String
The type of cloud connector created.
Instance Attribute Details
#description ⇒ String
A description of the C2C connector.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1708 class GetCloudConnectorResponse < Struct.new( :name, :endpoint_config, :description, :endpoint_type, :id, :type) SENSITIVE = [] include Aws::Structure end |
#endpoint_config ⇒ Types::EndpointConfig
The configuration details for the cloud connector endpoint, including connection parameters and authentication requirements.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1708 class GetCloudConnectorResponse < Struct.new( :name, :endpoint_config, :description, :endpoint_type, :id, :type) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of endpoint used for the cloud connector, which defines how the connector communicates with external services.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1708 class GetCloudConnectorResponse < Struct.new( :name, :endpoint_config, :description, :endpoint_type, :id, :type) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the cloud connector.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1708 class GetCloudConnectorResponse < Struct.new( :name, :endpoint_config, :description, :endpoint_type, :id, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The display name of the C2C connector.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1708 class GetCloudConnectorResponse < Struct.new( :name, :endpoint_config, :description, :endpoint_type, :id, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of cloud connector created.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1708 class GetCloudConnectorResponse < Struct.new( :name, :endpoint_config, :description, :endpoint_type, :id, :type) SENSITIVE = [] include Aws::Structure end |