Class: Aws::IoTManagedIntegrations::Types::GetCredentialLockerResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::GetCredentialLockerResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[:name, :tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the credential locker.
-
#created_at ⇒ Time
The timestamp value of when the credential locker requset occurred.
-
#id ⇒ String
The identifier of the credential locker.
-
#name ⇒ String
The name of the credential locker.
-
#tags ⇒ Hash<String,String>
A set of key/value pairs that are used to manage the credential locker.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the credential locker.
1810 1811 1812 1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1810 class GetCredentialLockerResponse < Struct.new( :id, :arn, :name, :created_at, :tags) SENSITIVE = [:name, :tags] include Aws::Structure end |
#created_at ⇒ Time
The timestamp value of when the credential locker requset occurred.
1810 1811 1812 1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1810 class GetCredentialLockerResponse < Struct.new( :id, :arn, :name, :created_at, :tags) SENSITIVE = [:name, :tags] include Aws::Structure end |
#id ⇒ String
The identifier of the credential locker.
1810 1811 1812 1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1810 class GetCredentialLockerResponse < Struct.new( :id, :arn, :name, :created_at, :tags) SENSITIVE = [:name, :tags] include Aws::Structure end |
#name ⇒ String
The name of the credential locker.
1810 1811 1812 1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1810 class GetCredentialLockerResponse < Struct.new( :id, :arn, :name, :created_at, :tags) SENSITIVE = [:name, :tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A set of key/value pairs that are used to manage the credential locker.
1810 1811 1812 1813 1814 1815 1816 1817 1818 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1810 class GetCredentialLockerResponse < Struct.new( :id, :arn, :name, :created_at, :tags) SENSITIVE = [:name, :tags] include Aws::Structure end |