Class: Aws::IoTManagedIntegrations::Types::GetHubConfigurationResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::GetHubConfigurationResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#hub_token_timer_expiry_setting_in_seconds ⇒ Integer
A user-defined integer value that represents the hub token timer expiry setting in seconds.
-
#updated_at ⇒ Time
The timestamp value of when the hub configuration was updated.
Instance Attribute Details
#hub_token_timer_expiry_setting_in_seconds ⇒ Integer
A user-defined integer value that represents the hub token timer expiry setting in seconds.
2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2035 class GetHubConfigurationResponse < Struct.new( :hub_token_timer_expiry_setting_in_seconds, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp value of when the hub configuration was updated.
2035 2036 2037 2038 2039 2040 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2035 class GetHubConfigurationResponse < Struct.new( :hub_token_timer_expiry_setting_in_seconds, :updated_at) SENSITIVE = [] include Aws::Structure end |