Class: Aws::IoTManagedIntegrations::Types::GetManagedThingConnectivityDataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotmanagedintegrations/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connectedBoolean

The connectivity status for a managed thing.

Returns:

  • (Boolean)


2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2124

class GetManagedThingConnectivityDataResponse < Struct.new(
  :managed_thing_id,
  :connected,
  :timestamp,
  :disconnect_reason)
  SENSITIVE = []
  include Aws::Structure
end

#disconnect_reasonString

The reason for the connectivity disconnect with the managed thing.

Returns:

  • (String)


2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2124

class GetManagedThingConnectivityDataResponse < Struct.new(
  :managed_thing_id,
  :connected,
  :timestamp,
  :disconnect_reason)
  SENSITIVE = []
  include Aws::Structure
end

#managed_thing_idString

The id of a managed thing.

Returns:

  • (String)


2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2124

class GetManagedThingConnectivityDataResponse < Struct.new(
  :managed_thing_id,
  :connected,
  :timestamp,
  :disconnect_reason)
  SENSITIVE = []
  include Aws::Structure
end

#timestampTime

The timestamp value of when the connectivity status for a managed thing was last taken.

Returns:

  • (Time)


2124
2125
2126
2127
2128
2129
2130
2131
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2124

class GetManagedThingConnectivityDataResponse < Struct.new(
  :managed_thing_id,
  :connected,
  :timestamp,
  :disconnect_reason)
  SENSITIVE = []
  include Aws::Structure
end