Class: Aws::IoTManagedIntegrations::Types::GetNotificationConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::GetNotificationConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_type ⇒ String
The type of event triggering a device notification to the customer-managed destination.
Instance Attribute Details
#event_type ⇒ String
The type of event triggering a device notification to the customer-managed destination.
1509 1510 1511 1512 1513 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 1509 class GetNotificationConfigurationRequest < Struct.new( :event_type) SENSITIVE = [] include Aws::Structure end |