Class: Aws::IoTManagedIntegrations::Types::GetProvisioningProfileResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::GetProvisioningProfileResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[:claim_certificate, :tags]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the provisioning profile.
-
#claim_certificate ⇒ String
The body of the PEM-encoded claim certificate.
-
#id ⇒ String
The provisioning profile id.
-
#name ⇒ String
The name of the provisioning profile.
-
#provisioning_type ⇒ String
The type of provisioning workflow the device uses for onboarding to IoT managed integrations.
-
#status ⇒ String
The status of a provisioning profile.
-
#tags ⇒ Hash<String,String>
A set of key/value pairs that are used to manage the provisioning profile.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the provisioning profile.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |
#claim_certificate ⇒ String
The body of the PEM-encoded claim certificate.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |
#id ⇒ String
The provisioning profile id.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |
#name ⇒ String
The name of the provisioning profile.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |
#provisioning_type ⇒ String
The type of provisioning workflow the device uses for onboarding to IoT managed integrations.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |
#status ⇒ String
The status of a provisioning profile.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
A set of key/value pairs that are used to manage the provisioning profile.
2590 2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2590 class GetProvisioningProfileResponse < Struct.new( :arn, :name, :provisioning_type, :id, :status, :claim_certificate, :tags) SENSITIVE = [:claim_certificate, :tags] include Aws::Structure end |