Class: Aws::IoTManagedIntegrations::Types::ManagedThingAssociation
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::ManagedThingAssociation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Overview
Structure representing an association between a managed thing and an account association, which connects a device to a third-party account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_association_id ⇒ String
The identifier of the account association in the association.
-
#managed_thing_association_status ⇒ String
The status of the registration between the managed thing and the account association.
-
#managed_thing_id ⇒ String
The identifier of the managed thing in the association.
Instance Attribute Details
#account_association_id ⇒ String
The identifier of the account association in the association.
3463 3464 3465 3466 3467 3468 3469 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3463 class ManagedThingAssociation < Struct.new( :managed_thing_id, :account_association_id, :managed_thing_association_status) SENSITIVE = [] include Aws::Structure end |
#managed_thing_association_status ⇒ String
The status of the registration between the managed thing and the account association. Indicates whether the device is pre-associated or fully associated with the account association.
3463 3464 3465 3466 3467 3468 3469 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3463 class ManagedThingAssociation < Struct.new( :managed_thing_id, :account_association_id, :managed_thing_association_status) SENSITIVE = [] include Aws::Structure end |
#managed_thing_id ⇒ String
The identifier of the managed thing in the association.
3463 3464 3465 3466 3467 3468 3469 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3463 class ManagedThingAssociation < Struct.new( :managed_thing_id, :account_association_id, :managed_thing_association_status) SENSITIVE = [] include Aws::Structure end |