Class: Aws::IoTManagedIntegrations::Types::ManagedThingSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::ManagedThingSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Overview
Structure representing one managed thing.
Constant Summary collapse
- SENSITIVE =
[:brand, :classification, :connector_device_id, :model, :owner, :serial_number]
Instance Attribute Summary collapse
-
#activated_at ⇒ Time
The timestampe value of when the managed thing was activated at.
-
#advertised_product_id ⇒ String
The id of the advertised product.
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the managed thing.
-
#brand ⇒ String
The brand of the device.
-
#classification ⇒ String
The classification of the managed thing such as light bulb or thermostat.
-
#connector_destination_id ⇒ String
The identifier of the connector destination associated with this managed thing, if applicable.
-
#connector_device_id ⇒ String
The third-party device id as defined by the connector.
-
#connector_policy_id ⇒ String
The id of the connector policy.
-
#created_at ⇒ Time
The timestamp value of when the device creation request occurred.
-
#credential_locker_id ⇒ String
The identifier of the credential locker for the managed thing.
-
#id ⇒ String
The id of the device.
-
#model ⇒ String
The model of the device.
-
#name ⇒ String
The name of the managed thing representing the physical device.
-
#owner ⇒ String
Owner of the device, usually an indication of whom the device belongs to.
-
#parent_controller_id ⇒ String
Id of the controller device used for the discovery job.
-
#provisioning_status ⇒ String
The provisioning status of the device in the provisioning workflow for onboarding to IoT managed integrations.
-
#role ⇒ String
The type of device used.
-
#serial_number ⇒ String
The serial number of the device.
-
#updated_at ⇒ Time
The timestamp value of when the managed thing was last updated at.
Instance Attribute Details
#activated_at ⇒ Time
The timestampe value of when the managed thing was activated at.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#advertised_product_id ⇒ String
The id of the advertised product.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#arn ⇒ String
The Amazon Resource Name (ARN) of the managed thing.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#brand ⇒ String
The brand of the device.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#classification ⇒ String
The classification of the managed thing such as light bulb or thermostat.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#connector_destination_id ⇒ String
The identifier of the connector destination associated with this managed thing, if applicable.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#connector_device_id ⇒ String
The third-party device id as defined by the connector. This device id must not contain personal identifiable information (PII).
<note markdown=“1”> This parameter is used for cloud-to-cloud devices only.
</note>
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#connector_policy_id ⇒ String
The id of the connector policy.
<note markdown=“1”> This parameter is used for cloud-to-cloud devices only.
</note>
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#created_at ⇒ Time
The timestamp value of when the device creation request occurred.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#credential_locker_id ⇒ String
The identifier of the credential locker for the managed thing.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#id ⇒ String
The id of the device.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#model ⇒ String
The model of the device.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#name ⇒ String
The name of the managed thing representing the physical device.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#owner ⇒ String
Owner of the device, usually an indication of whom the device belongs to. This value should not contain personal identifiable information.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#parent_controller_id ⇒ String
Id of the controller device used for the discovery job.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#provisioning_status ⇒ String
The provisioning status of the device in the provisioning workflow for onboarding to IoT managed integrations. For more information, see [Device Provisioning].
[1]: docs.aws.amazon.com/iot-mi/latest/devguide/device-provisioning.html
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#role ⇒ String
The type of device used. This will be the Amazon Web Services hub controller, cloud device, or IoT device.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#serial_number ⇒ String
The serial number of the device.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp value of when the managed thing was last updated at.
3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 3609 3610 3611 3612 3613 3614 3615 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3593 class ManagedThingSummary < Struct.new( :id, :arn, :advertised_product_id, :brand, :classification, :connector_device_id, :connector_policy_id, :connector_destination_id, :model, :name, :owner, :credential_locker_id, :parent_controller_id, :provisioning_status, :role, :serial_number, :created_at, :updated_at, :activated_at) SENSITIVE = [:brand, :classification, :connector_device_id, :model, :owner, :serial_number] include Aws::Structure end |