Class: Aws::IoTManagedIntegrations::Types::MatterCapabilityReportAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::MatterCapabilityReportAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Overview
Matter attribute used in capability report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The id of the Matter attribute.
-
#name ⇒ String
Name for the Amazon Web Services Matter capability report attribute.
-
#value ⇒ Hash, ...
Value for the Amazon Web Services Matter capability report attribute.
Instance Attribute Details
#id ⇒ String
The id of the Matter attribute.
3506 3507 3508 3509 3510 3511 3512 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3506 class MatterCapabilityReportAttribute < Struct.new( :id, :name, :value) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name for the Amazon Web Services Matter capability report attribute.
3506 3507 3508 3509 3510 3511 3512 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3506 class MatterCapabilityReportAttribute < Struct.new( :id, :name, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ Hash, ...
Value for the Amazon Web Services Matter capability report attribute.
3506 3507 3508 3509 3510 3511 3512 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3506 class MatterCapabilityReportAttribute < Struct.new( :id, :name, :value) SENSITIVE = [] include Aws::Structure end |