Class: Aws::IoTManagedIntegrations::Types::MatterCapabilityReportEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::MatterCapabilityReportEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Overview
Matter endpoint used in capability report.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_clusters ⇒ Array<String>
Semantic information related to endpoint.
-
#clusters ⇒ Array<Types::MatterCapabilityReportCluster>
Matter clusters used in capability report.
-
#device_types ⇒ Array<String>
The type of device.
-
#id ⇒ String
The id of the Amazon Web Services Matter capability report endpoint.
-
#parts ⇒ Array<String>
Heirachy of child endpoints contained in the given endpoint.
-
#semantic_tags ⇒ Array<String>
Semantic information related to endpoint.
Instance Attribute Details
#client_clusters ⇒ Array<String>
Semantic information related to endpoint.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3756 class MatterCapabilityReportEndpoint < Struct.new( :id, :device_types, :clusters, :parts, :semantic_tags, :client_clusters) SENSITIVE = [] include Aws::Structure end |
#clusters ⇒ Array<Types::MatterCapabilityReportCluster>
Matter clusters used in capability report.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3756 class MatterCapabilityReportEndpoint < Struct.new( :id, :device_types, :clusters, :parts, :semantic_tags, :client_clusters) SENSITIVE = [] include Aws::Structure end |
#device_types ⇒ Array<String>
The type of device.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3756 class MatterCapabilityReportEndpoint < Struct.new( :id, :device_types, :clusters, :parts, :semantic_tags, :client_clusters) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The id of the Amazon Web Services Matter capability report endpoint.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3756 class MatterCapabilityReportEndpoint < Struct.new( :id, :device_types, :clusters, :parts, :semantic_tags, :client_clusters) SENSITIVE = [] include Aws::Structure end |
#parts ⇒ Array<String>
Heirachy of child endpoints contained in the given endpoint.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3756 class MatterCapabilityReportEndpoint < Struct.new( :id, :device_types, :clusters, :parts, :semantic_tags, :client_clusters) SENSITIVE = [] include Aws::Structure end |
#semantic_tags ⇒ Array<String>
Semantic information related to endpoint.
3756 3757 3758 3759 3760 3761 3762 3763 3764 3765 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 3756 class MatterCapabilityReportEndpoint < Struct.new( :id, :device_types, :clusters, :parts, :semantic_tags, :client_clusters) SENSITIVE = [] include Aws::Structure end |