Class: Aws::IoTManagedIntegrations::Types::OtaTaskSchedulingConfig
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::OtaTaskSchedulingConfig
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Overview
Over-the-air (OTA) task scheduling config.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_behavior ⇒ String
Specifies the end behavior for all task executions after a task reaches the selected ‘endTime`.
-
#end_time ⇒ String
The time an over-the-air (OTA) task will stop.
-
#maintenance_windows ⇒ Array<Types::ScheduleMaintenanceWindow>
Maintenance window list for over-the-air (OTA) task scheduling config.
-
#start_time ⇒ String
The time an over-the-air (OTA) task will start.
Instance Attribute Details
#end_behavior ⇒ String
Specifies the end behavior for all task executions after a task reaches the selected ‘endTime`. If `endTime` is not selected when creating the task, then `endBehavior` does not apply.
2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2559 class OtaTaskSchedulingConfig < Struct.new( :end_behavior, :end_time, :maintenance_windows, :start_time) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ String
The time an over-the-air (OTA) task will stop.
2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2559 class OtaTaskSchedulingConfig < Struct.new( :end_behavior, :end_time, :maintenance_windows, :start_time) SENSITIVE = [] include Aws::Structure end |
#maintenance_windows ⇒ Array<Types::ScheduleMaintenanceWindow>
Maintenance window list for over-the-air (OTA) task scheduling config.
2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2559 class OtaTaskSchedulingConfig < Struct.new( :end_behavior, :end_time, :maintenance_windows, :start_time) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ String
The time an over-the-air (OTA) task will start.
2559 2560 2561 2562 2563 2564 2565 2566 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2559 class OtaTaskSchedulingConfig < Struct.new( :end_behavior, :end_time, :maintenance_windows, :start_time) SENSITIVE = [] include Aws::Structure end |