Class: Aws::IoTManagedIntegrations::Types::PutDefaultEncryptionConfigurationResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotmanagedintegrations/types.rb

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_statusTypes::ConfigurationStatus

Provides the status of the default encryption configuration for an Amazon Web Services account.



4207
4208
4209
4210
4211
4212
4213
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4207

class PutDefaultEncryptionConfigurationResponse < Struct.new(
  :configuration_status,
  :encryption_type,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#encryption_typeString

The type of encryption used for the encryption configuration.

Returns:

  • (String)


4207
4208
4209
4210
4211
4212
4213
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4207

class PutDefaultEncryptionConfigurationResponse < Struct.new(
  :configuration_status,
  :encryption_type,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The Key Amazon Resource Name (ARN) of the AWS KMS key used for KMS encryption if you use ‘KMS_BASED_ENCRYPTION`.

Returns:

  • (String)


4207
4208
4209
4210
4211
4212
4213
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4207

class PutDefaultEncryptionConfigurationResponse < Struct.new(
  :configuration_status,
  :encryption_type,
  :kms_key_arn)
  SENSITIVE = []
  include Aws::Structure
end