Class: Aws::IoTManagedIntegrations::Types::RolloutRateIncreaseCriteria

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-iotmanagedintegrations/types.rb

Overview

Structure representing rollout config criteria.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#number_of_notified_thingsInteger

The threshold for number of notified things that will initiate the increase in rate of rollout.

Returns:

  • (Integer)


4373
4374
4375
4376
4377
4378
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4373

class RolloutRateIncreaseCriteria < Struct.new(
  :number_of_notified_things,
  :number_of_succeeded_things)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_succeeded_thingsInteger

The threshold for number of succeeded things that will initiate the increase in rate of rollout.

Returns:

  • (Integer)


4373
4374
4375
4376
4377
4378
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4373

class RolloutRateIncreaseCriteria < Struct.new(
  :number_of_notified_things,
  :number_of_succeeded_things)
  SENSITIVE = []
  include Aws::Structure
end