Class: Aws::IoTManagedIntegrations::Types::SendConnectorEventRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::SendConnectorEventRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[:user_id, :message, :connector_device_id]
Instance Attribute Summary collapse
-
#connector_device_id ⇒ String
The third-party device id as defined by the connector.
-
#connector_id ⇒ String
The id of the connector between the third-party cloud provider and IoT managed integrations.
-
#device_discovery_id ⇒ String
The id for the device discovery job.
-
#devices ⇒ Array<Types::Device>
The list of devices.
-
#matter_endpoint ⇒ Types::MatterEndpoint
The device endpoint.
-
#message ⇒ String
The device state change event payload.
-
#operation ⇒ String
The Open Connectivity Foundation (OCF) operation requested to be performed on the managed thing.
-
#operation_version ⇒ String
The Open Connectivity Foundation (OCF) security specification version for the operation being requested on the managed thing.
-
#status_code ⇒ Integer
The status code of the Open Connectivity Foundation (OCF) operation being performed on the managed thing.
-
#trace_id ⇒ String
The trace request identifier.
-
#user_id ⇒ String
The id of the third-party cloud provider.
Instance Attribute Details
#connector_device_id ⇒ String
The third-party device id as defined by the connector. This device id must not contain personal identifiable information (PII).
<note markdown=“1”> This parameter is used for cloud-to-cloud devices only.
</note>
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#connector_id ⇒ String
The id of the connector between the third-party cloud provider and IoT managed integrations.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#device_discovery_id ⇒ String
The id for the device discovery job.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#devices ⇒ Array<Types::Device>
The list of devices.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#matter_endpoint ⇒ Types::MatterEndpoint
The device endpoint.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#message ⇒ String
The device state change event payload.
This parameter will include the following three fields:
-
‘uri`: `schema auc://<PARTNER-DEVICE-ID>/ResourcePath` (The `Resourcepath` corresponds to an OCF resource.)
-
‘op`: For device state changes, this field must populate as `n+d`.
-
‘cn`: The content depends on the OCF resource referenced in `ResourcePath`.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#operation ⇒ String
The Open Connectivity Foundation (OCF) operation requested to be performed on the managed thing.
<note markdown=“1”> The field op can have a value of “I” or “U”. The field “cn” will contain the capability types.
</note>
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#operation_version ⇒ String
The Open Connectivity Foundation (OCF) security specification version for the operation being requested on the managed thing. For more information, see [OCF Security Specification].
[1]: openconnectivity.org/specs/OCF_Security_Specification_v1.0.0.pdf
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#status_code ⇒ Integer
The status code of the Open Connectivity Foundation (OCF) operation being performed on the managed thing.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#trace_id ⇒ String
The trace request identifier. This is generated by IoT managed integrations and can be used to trace this command and its related operations in CloudWatch.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |
#user_id ⇒ String
The id of the third-party cloud provider.
4582 4583 4584 4585 4586 4587 4588 4589 4590 4591 4592 4593 4594 4595 4596 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4582 class SendConnectorEventRequest < Struct.new( :connector_id, :user_id, :operation, :operation_version, :status_code, :message, :device_discovery_id, :connector_device_id, :trace_id, :devices, :matter_endpoint) SENSITIVE = [:user_id, :message, :connector_device_id] include Aws::Structure end |