Class: Aws::IoTManagedIntegrations::Types::SendManagedThingCommandRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::SendManagedThingCommandRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_association_id ⇒ String
The identifier of the account association to use when sending a command to a managed thing.
-
#connector_association_id ⇒ String
The ID tracking the current discovery process for one connector association.
-
#endpoints ⇒ Array<Types::CommandEndpoint>
The device endpoint.
-
#managed_thing_id ⇒ String
The id of the device.
Instance Attribute Details
#account_association_id ⇒ String
The identifier of the account association to use when sending a command to a managed thing.
4627 4628 4629 4630 4631 4632 4633 4634 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4627 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id, :account_association_id) SENSITIVE = [] include Aws::Structure end |
#connector_association_id ⇒ String
The ID tracking the current discovery process for one connector association.
4627 4628 4629 4630 4631 4632 4633 4634 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4627 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id, :account_association_id) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Array<Types::CommandEndpoint>
The device endpoint.
4627 4628 4629 4630 4631 4632 4633 4634 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4627 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id, :account_association_id) SENSITIVE = [] include Aws::Structure end |
#managed_thing_id ⇒ String
The id of the device.
4627 4628 4629 4630 4631 4632 4633 4634 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4627 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id, :account_association_id) SENSITIVE = [] include Aws::Structure end |