Class: Aws::IoTManagedIntegrations::Types::SendManagedThingCommandResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::SendManagedThingCommandResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#trace_id ⇒ String
The trace request identifier.
Instance Attribute Details
#trace_id ⇒ String
The trace request identifier. This is generated by IoT managed integrations and can be used to trace this command and its related operations in CloudWatch.
4642 4643 4644 4645 4646 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4642 class SendManagedThingCommandResponse < Struct.new( :trace_id) SENSITIVE = [] include Aws::Structure end |