Class: Aws::IoTManagedIntegrations::Types::UpdateCloudConnectorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::UpdateCloudConnectorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
The new description to assign to the cloud connector.
-
#identifier ⇒ String
The unique identifier of the cloud connector to update.
-
#name ⇒ String
The new display name to assign to the cloud connector.
Instance Attribute Details
#description ⇒ String
The new description to assign to the cloud connector.
4984 4985 4986 4987 4988 4989 4990 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4984 class UpdateCloudConnectorRequest < Struct.new( :identifier, :name, :description) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the cloud connector to update.
4984 4985 4986 4987 4988 4989 4990 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4984 class UpdateCloudConnectorRequest < Struct.new( :identifier, :name, :description) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The new display name to assign to the cloud connector.
4984 4985 4986 4987 4988 4989 4990 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 4984 class UpdateCloudConnectorRequest < Struct.new( :identifier, :name, :description) SENSITIVE = [] include Aws::Structure end |