Class: Aws::IoTManagedIntegrations::Types::UpdateConnectorDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::UpdateConnectorDestinationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_config ⇒ Types::AuthConfigUpdate
The updated authentication configuration details for the connector destination.
-
#auth_type ⇒ String
The new authentication type to use for the connector destination.
-
#description ⇒ String
The new description to assign to the connector destination.
-
#identifier ⇒ String
The unique identifier of the connector destination to update.
-
#name ⇒ String
The new display name to assign to the connector destination.
-
#secrets_manager ⇒ Types::SecretsManager
The updated AWS Secrets Manager configuration for the connector destination.
Instance Attribute Details
#auth_config ⇒ Types::AuthConfigUpdate
The updated authentication configuration details for the connector destination.
5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5018 class UpdateConnectorDestinationRequest < Struct.new( :identifier, :description, :name, :auth_type, :auth_config, :secrets_manager) SENSITIVE = [] include Aws::Structure end |
#auth_type ⇒ String
The new authentication type to use for the connector destination.
5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5018 class UpdateConnectorDestinationRequest < Struct.new( :identifier, :description, :name, :auth_type, :auth_config, :secrets_manager) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The new description to assign to the connector destination.
5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5018 class UpdateConnectorDestinationRequest < Struct.new( :identifier, :description, :name, :auth_type, :auth_config, :secrets_manager) SENSITIVE = [] include Aws::Structure end |
#identifier ⇒ String
The unique identifier of the connector destination to update.
5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5018 class UpdateConnectorDestinationRequest < Struct.new( :identifier, :description, :name, :auth_type, :auth_config, :secrets_manager) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The new display name to assign to the connector destination.
5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5018 class UpdateConnectorDestinationRequest < Struct.new( :identifier, :description, :name, :auth_type, :auth_config, :secrets_manager) SENSITIVE = [] include Aws::Structure end |
#secrets_manager ⇒ Types::SecretsManager
The updated AWS Secrets Manager configuration for the connector destination.
5018 5019 5020 5021 5022 5023 5024 5025 5026 5027 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5018 class UpdateConnectorDestinationRequest < Struct.new( :identifier, :description, :name, :auth_type, :auth_config, :secrets_manager) SENSITIVE = [] include Aws::Structure end |