Class: Aws::IoTManagedIntegrations::Types::UpdateEventLogConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::UpdateEventLogConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#event_log_level ⇒ String
The log level for the event in terms of severity.
-
#id ⇒ String
The log configuration id.
Instance Attribute Details
#event_log_level ⇒ String
The log level for the event in terms of severity.
5067 5068 5069 5070 5071 5072 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5067 class UpdateEventLogConfigurationRequest < Struct.new( :id, :event_log_level) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The log configuration id.
5067 5068 5069 5070 5071 5072 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5067 class UpdateEventLogConfigurationRequest < Struct.new( :id, :event_log_level) SENSITIVE = [] include Aws::Structure end |