Class: Aws::IoTManagedIntegrations::Types::UpdateManagedThingRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::UpdateManagedThingRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[:owner, :serial_number, :brand, :model, :classification]
Instance Attribute Summary collapse
-
#brand ⇒ String
The brand of the device.
-
#capabilities ⇒ String
The capabilities of the device such as light bulb.
-
#capability_report ⇒ Types::CapabilityReport
A report of the capabilities for the managed thing.
-
#capability_schemas ⇒ Array<Types::CapabilitySchemaItem>
The updated capability schemas that define the functionality and features supported by the managed thing.
-
#classification ⇒ String
The classification of the managed thing such as light bulb or thermostat.
-
#credential_locker_id ⇒ String
The identifier of the credential for the managed thing.
-
#hub_network_mode ⇒ String
The network mode for the hub-connected device.
-
#identifier ⇒ String
The id of the managed thing.
-
#meta_data ⇒ Hash<String,String>
The metadata for the managed thing.
-
#model ⇒ String
The model of the device.
-
#name ⇒ String
The name of the managed thing representing the physical device.
-
#owner ⇒ String
Owner of the device, usually an indication of whom the device belongs to.
-
#serial_number ⇒ String
The serial number of the device.
-
#wi_fi_simple_setup_configuration ⇒ Types::WiFiSimpleSetupConfiguration
The Wi-Fi Simple Setup configuration for the managed thing, which defines provisioning capabilities and timeout settings.
Instance Attribute Details
#brand ⇒ String
The brand of the device.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#capabilities ⇒ String
The capabilities of the device such as light bulb.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#capability_report ⇒ Types::CapabilityReport
A report of the capabilities for the managed thing.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#capability_schemas ⇒ Array<Types::CapabilitySchemaItem>
The updated capability schemas that define the functionality and features supported by the managed thing.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#classification ⇒ String
The classification of the managed thing such as light bulb or thermostat.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#credential_locker_id ⇒ String
The identifier of the credential for the managed thing.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#hub_network_mode ⇒ String
The network mode for the hub-connected device.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#identifier ⇒ String
The id of the managed thing.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#meta_data ⇒ Hash<String,String>
The metadata for the managed thing.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#model ⇒ String
The model of the device.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#name ⇒ String
The name of the managed thing representing the physical device.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#owner ⇒ String
Owner of the device, usually an indication of whom the device belongs to. This value should not contain personal identifiable information.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#serial_number ⇒ String
The serial number of the device.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |
#wi_fi_simple_setup_configuration ⇒ Types::WiFiSimpleSetupConfiguration
The Wi-Fi Simple Setup configuration for the managed thing, which defines provisioning capabilities and timeout settings.
5135 5136 5137 5138 5139 5140 5141 5142 5143 5144 5145 5146 5147 5148 5149 5150 5151 5152 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 5135 class UpdateManagedThingRequest < Struct.new( :identifier, :owner, :credential_locker_id, :serial_number, :wi_fi_simple_setup_configuration, :brand, :model, :name, :capability_report, :capability_schemas, :capabilities, :classification, :hub_network_mode, :meta_data) SENSITIVE = [:owner, :serial_number, :brand, :model, :classification] include Aws::Structure end |