Class: Aws::IoTManagedIntegrations::Types::SendManagedThingCommandRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IoTManagedIntegrations::Types::SendManagedThingCommandRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-iotmanagedintegrations/types.rb
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connector_association_id ⇒ String
The ID tracking the current discovery process for one connector association.
-
#endpoints ⇒ Array<Types::CommandEndpoint>
The device endpoint.
-
#managed_thing_id ⇒ String
The id of the device.
Instance Attribute Details
#connector_association_id ⇒ String
The ID tracking the current discovery process for one connector association.
2942 2943 2944 2945 2946 2947 2948 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2942 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id) SENSITIVE = [] include Aws::Structure end |
#endpoints ⇒ Array<Types::CommandEndpoint>
The device endpoint.
2942 2943 2944 2945 2946 2947 2948 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2942 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id) SENSITIVE = [] include Aws::Structure end |
#managed_thing_id ⇒ String
The id of the device.
2942 2943 2944 2945 2946 2947 2948 |
# File 'lib/aws-sdk-iotmanagedintegrations/types.rb', line 2942 class SendManagedThingCommandRequest < Struct.new( :managed_thing_id, :endpoints, :connector_association_id) SENSITIVE = [] include Aws::Structure end |